@@ -8,7 +8,7 @@ from ewoxcore.decorators.serializable import Serializable
 class ResponseModel:
     def __init__(self, data: str="", code: int=int(StatusCode.Ok), message: str="", iscompressed: bool=True, correlationid: str=""):
         self.data:str = data
-        self.code:int = code
+        self.code:int = int(code)
         self.message:str = message
         self.iscompressed:bool = iscompressed
         self.correlationid:str = correlationid
